pub struct CandidatePeer<N: Network> {
pub listener_addr: SocketAddr,
pub trusted: bool,
pub last_height_seen: Option<u32>,
pub last_connection_attempt: Option<Instant>,
pub total_connection_attempts: u32,
pub last_known_aleo_addr: Option<Address<N>>,
}Expand description
A candidate peer.
Fields
listener_addr: SocketAddrThe listening address of a candidate peer.
trusted: boolIndicates whether the peer is considered trusted.
last_height_seen: Option<u32>The latest block height known to be associated with the peer.
last_connection_attempt: Option<Instant>The last time we attempted to connect to the peer.
None if there was no attempt to connect since the peer was last connected, or no attempt at all.
total_connection_attempts: u32The total number of connection attempts, since the peer was last connected.
last_known_aleo_addr: Option<Address<N>>The last known Aleo address of this peer, carried over from a prior connection. Used to detect when a validator reconnects from a different IP address.