pub struct ConnectedPeer<N: Network> {
pub listener_addr: SocketAddr,
pub connected_addr: SocketAddr,
pub connection_mode: ConnectionMode,
pub trusted: bool,
pub aleo_addr: Address<N>,
pub node_type: NodeType,
pub version: u32,
pub last_height_seen: Option<u32>,
pub first_seen: Instant,
pub last_seen: Instant,
}Expand description
A fully connected peer.
Fields
listener_addr: SocketAddrThe listener address of the peer.
connected_addr: SocketAddrThe connected address of the peer.
connection_mode: ConnectionModeIndicates whether this is a Router or a Gateway connection for the peer.
trusted: boolIndicates whether the peer is considered trusted.
aleo_addr: Address<N>The Aleo address of the peer.
node_type: NodeTypeThe node type of the peer.
version: u32The message version of the peer.
last_height_seen: Option<u32>The latest block height known to be associated with the peer.
first_seen: InstantThe timestamp of the first message received from the peer.
last_seen: InstantThe timestamp of the last message received from this peer.