pub struct ConnectingPeer {
pub listener_addr: SocketAddr,
pub trusted: bool,
pub last_connection_attempt: Option<Instant>,
pub total_connection_attempts: u32,
}Expand description
A connecting peer.
Fields
listener_addr: SocketAddrThe listening address of a connecting peer.
trusted: boolIndicates whether the peer is considered trusted.
last_connection_attempt: Option<Instant>The last time we attempted to connect to the peer.
total_connection_attempts: u32The total number of connection attempts, since the peer was last connected.