Module resolver
snarkos_
node_
network
4.5.0
Module resolver
Module Items
Structs
In crate snarkos_
node_
network
snarkos_node_network
Module
resolver
Structs

Resolver
The resolver contains additional reverse maps for peers which are not available by default to the implementors of PeerPoolHandling (which already contains maps from the peer’s listening address to their various components).